==> terasoluna-batch4j-blank_3.1.2.zip: jp/terasoluna/fw/collector/vo/DataValueObject.java <==
/*
 * Copyright (c) 2011 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.fw.collector.vo;

import jp.terasoluna.fw.collector.validate.ValidateErrorStatus;

/**
 * DataValueObject.<br>
 * L[Ƀf[^Oi[ۂ̔B
 */
public class DataValueObject {
    /** f[^JEgi擾f[^ڂ̃f[^i1=1jj */
    protected long dataCount = -1;

    /** sʃf[^ */
    protected Object value = null;

    /** O */
    protected Throwable throwable = null;

    /** ̓`FbNXe[^X */
    protected ValidateErrorStatus validateStatus = null;

    /** RN^Xe[^X */
    protected CollectorStatus collectorStatus = null;

    /**
     * RXgN^isʃf[^j<br>
     * @param value Object sʃf[^
     */
    public DataValueObject(Object value) {
        this.value = value;
    }

    /**
     * RXgN^isʃf[^j<br>
     * @param value Object sʃf[^
     * @param dataCount long f[^JE^
     */
    public DataValueObject(Object value, long dataCount) {
        this.value = value;
        this.dataCount = dataCount;
    }

    /**
     * RXgN^iOj<br>
     * @param throwable Throwable O
     */
    public DataValueObject(Throwable throwable) {
        this.throwable = throwable;
    }

    /**
     * RXgN^iOj<br>
     * @param throwable Throwable O
     * @param dataCount long f[^JE^
     */
    public DataValueObject(Throwable throwable, long dataCount) {
        this.throwable = throwable;
        this.dataCount = dataCount;
    }

    /**
     * ̓`FbNXe[^X<br>
     * @param validateStatus ValidateStatus ̓`FbNXe[^X
     */
    public DataValueObject(ValidateErrorStatus validateStatus) {
        this.validateStatus = validateStatus;
    }

    /**
     * RXgN^iRN^Xe[^Xj<br>
     * @param collectorStatus CollectorStatus RN^Xe[^X
     */
    public DataValueObject(CollectorStatus collectorStatus) {
        this.collectorStatus = collectorStatus;
    }

    /**
     * f[^JEg擾.<br>
     * @return long
     */
    public long getDataCount() {
        return dataCount;
    }

    /**
     * sʃf[^<br>
     * @return sʃf[^
     */
    public Object getValue() {
        return value;
    }

    /**
     * O<br>
     * @return O
     */
    public Throwable getThrowable() {
        return throwable;
    }

    /**
     * ̓`FbNXe[^X<br>
     * @return ̓`FbNXe[^X
     */
    public ValidateErrorStatus getValidateStatus() {
        return validateStatus;
    }

    /**
     * RN^Xe[^X<br>
     * @return RN^Xe[^X
     */
    public CollectorStatus getCollectorStatus() {
        return collectorStatus;
    }

    /**
     * RN^Xe[^X<br>
     * @param collectorStatus RN^Xe[^X
     */
    public void setCollectorStatus(CollectorStatus collectorStatus) {
        this.collectorStatus = collectorStatus;
    }
}

==> terasoluna-batch4j-blank_3.2.0.zip: jp/terasoluna/fw/collector/vo/DataValueObject.java <==
/*
 * Copyright (c) 2011 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.fw.collector.vo;

import jp.terasoluna.fw.collector.exception.CollectorExceptionHandlerStatus;
import jp.terasoluna.fw.collector.validate.ValidateErrorStatus;

/**
 * DataValueObject.<br>
 * L[Ƀf[^Oi[ۂ̔B
 */
public class DataValueObject {
    /** f[^JEgi擾f[^ڂ̃f[^i1=1jj */
    protected long dataCount = -1;

    /** sʃf[^ */
    protected Object value = null;

    /** O */
    protected Throwable throwable = null;

    /** ̓`FbNXe[^X */
    protected ValidateErrorStatus validateStatus = null;

    /** RN^Xe[^X */
    protected CollectorStatus collectorStatus = null;

    /** OnhXe[^X */
    protected CollectorExceptionHandlerStatus exceptionHandlerStatus = null;

    /**
     * RXgN^isʃf[^j<br>
     * @param value Object sʃf[^
     */
    public DataValueObject(Object value) {
        this.value = value;
    }

    /**
     * RXgN^isʃf[^j<br>
     * @param value Object sʃf[^
     * @param dataCount long f[^JE^
     */
    public DataValueObject(Object value, long dataCount) {
        this.value = value;
        this.dataCount = dataCount;
    }

    /**
     * RXgN^iOj<br>
     * @param throwable Throwable O
     */
    public DataValueObject(Throwable throwable) {
        this.throwable = throwable;
    }

    /**
     * RXgN^iOj<br>
     * @param throwable Throwable O
     * @param dataCount long f[^JE^
     */
    public DataValueObject(Throwable throwable, long dataCount) {
        this.throwable = throwable;
        this.dataCount = dataCount;
    }

    /**
     * RXgN^i̓`FbNXe[^Xj<br>
     * @param validateStatus ValidateStatus ̓`FbNXe[^X
     */
    public DataValueObject(ValidateErrorStatus validateStatus) {
        this.validateStatus = validateStatus;
    }

    /**
     * RXgN^iRN^Xe[^Xj<br>
     * @param collectorStatus CollectorStatus RN^Xe[^X
     */
    public DataValueObject(CollectorStatus collectorStatus) {
        this.collectorStatus = collectorStatus;
    }

    /**
     * f[^JEg擾.<br>
     * @return long
     */
    public long getDataCount() {
        return dataCount;
    }

    /**
     * sʃf[^<br>
     * @return sʃf[^
     */
    public Object getValue() {
        return value;
    }

    /**
     * O<br>
     * @return O
     */
    public Throwable getThrowable() {
        return throwable;
    }

    /**
     * ̓`FbNXe[^X<br>
     * @return ̓`FbNXe[^X
     */
    public ValidateErrorStatus getValidateStatus() {
        return validateStatus;
    }

    /**
     * RN^Xe[^X<br>
     * @return RN^Xe[^X
     */
    public CollectorStatus getCollectorStatus() {
        return collectorStatus;
    }

    /**
     * RN^Xe[^X<br>
     * @param collectorStatus RN^Xe[^X
     */
    public void setCollectorStatus(CollectorStatus collectorStatus) {
        this.collectorStatus = collectorStatus;
    }

    /**
     * OnhXe[^X<br>
     * @return OnhXe[^X
     */
    public CollectorExceptionHandlerStatus getExceptionHandlerStatus() {
        return exceptionHandlerStatus;
    }

    /**
     * OnhXe[^X<br>
     * @param exceptionHandlerStatus OnhXe[^X
     */
    public void setExceptionHandlerStatus(
            CollectorExceptionHandlerStatus exceptionHandlerStatus) {
        this.exceptionHandlerStatus = exceptionHandlerStatus;
    }
}
